diff --git a/modules/image/Image_gan/style_transfer/lapstyle_circuit/module.py b/modules/image/Image_gan/style_transfer/lapstyle_circuit/module.py
index d657fb88ba9b6c8c6f30856caf2bb9b440b04a90..fea1bb2ec7d5633144cde9170985302798ae4bf5 100644
--- a/modules/image/Image_gan/style_transfer/lapstyle_circuit/module.py
+++ b/modules/image/Image_gan/style_transfer/lapstyle_circuit/module.py
@@ -44,11 +44,11 @@ class Lapstyle_circuit:
self.network = LapStylePredictor(weight_path=self.pretrained_model)
def style_transfer(self,
- images=None,
- paths=None,
- output_dir='./transfer_result/',
- use_gpu=False,
- visualization=True):
+ images: list = None,
+ paths: list = None,
+ output_dir: str = './transfer_result/',
+ use_gpu: bool = False,
+ visualization: bool = True):
'''
Transfer a image to circuit style.
@@ -59,13 +59,10 @@ class Lapstyle_circuit:
- content (str): path to input image;
- style (str) : path to style image;
- output_dir: the dir to save the results
- use_gpu: if True, use gpu to perform the computation, otherwise cpu.
- visualization: if True, save results in output_dir.
+ output_dir (str): the dir to save the results
+ use_gpu (bool): if True, use gpu to perform the computation, otherwise cpu.
+ visualization (bool): if True, save results in output_dir.
- output_dir: the dir to save the results
- use_gpu: if True, use gpu to perform the computation, otherwise cpu.
- visualization: if True, save results in output_dir.
'''
results = []
paddle.disable_static()